@@ -264,6 +264,14 @@ type RuntimeHandler struct {
 	// Output of the "features" subcommand.
 	// This is populated dynamically and not read from config.
 	features runtimeHandlerFeatures
+
+	// Inheritance request
+	// Fill in the Runtime information (paths and type) from the default runtime
+	InheritDefaultRuntime bool `toml:"inherit_default_runtime,omitempty"`
+
+	// Default annotations specified for runtime handler if they're not overridden by
+	// the pod spec.
+	DefaultAnnotations map[string]string `toml:"default_annotations,omitempty"`
 }
 
 // Multiple runtime Handlers in a map.
@@ -562,6 +570,11 @@ type ImageConfig struct {
 	// reload the mirror registry when there is an update to the
 	// 'registries.conf.d' directory.
 	AutoReloadRegistries bool `toml:"auto_reload_registries"`
+	// PullProgressTimeout is the timeout for an image pull to make progress
+	// until the pull operation gets canceled. This value will be also used for
+	// calculating the pull progress interval to pullProgressTimeout / 10.
+	// Can be set to 0 to disable the timeout as well as the progress output.
+	PullProgressTimeout time.Duration `toml:"pull_progress_timeout"`
 }
 
 // NetworkConfig represents the "crio.network" TOML config table.
@@ -938,11 +951,12 @@ func DefaultConfig() (*Config, error) {
 			EnableCriuSupport:           true,
 		},
 		ImageConfig: ImageConfig{
-			DefaultTransport:   "docker://",
-			PauseImage:         DefaultPauseImage,
-			PauseCommand:       "/pause",
-			ImageVolumes:       ImageVolumesMkdir,
-			SignaturePolicyDir: "/etc/crio/policies",
+			DefaultTransport:    "docker://",
+			PauseImage:          DefaultPauseImage,
+			PauseCommand:        "/pause",
+			ImageVolumes:        ImageVolumesMkdir,
+			SignaturePolicyDir:  "/etc/crio/policies",
+			PullProgressTimeout: 10 * time.Second,
 		},
 		NetworkConfig: NetworkConfig{
 			NetworkDir: cniConfigDir,
@@ -1294,6 +1308,30 @@ func defaultRuntimeHandler() *RuntimeHandler {
 func (c *RuntimeConfig) ValidateRuntimes() error {
 	var failedValidation []string
 
+	// Update the default runtime paths in all runtimes that are asking for inheritance
+	for name := range c.Runtimes {
+		if !c.Runtimes[name].InheritDefaultRuntime {
+			continue
+		}
+
+		logrus.Infof("Inheriting runtime configuration %q from %q", name, c.DefaultRuntime)
+
+		c.Runtimes[name].RuntimePath = c.Runtimes[c.DefaultRuntime].RuntimePath
+		// An empty RuntimePath causes cri-o to look for a binary named `name`,
+		// but we inherit from the default - look for binary called c.DefaultRuntime
+		// The validator will check the binary is valid below.
+		if c.Runtimes[name].RuntimePath == "" {
+			executable, err := exec.LookPath(c.DefaultRuntime)
+			if err == nil {
+				c.Runtimes[name].RuntimePath = executable
+			}
+		}
+
+		c.Runtimes[name].RuntimeType = c.Runtimes[c.DefaultRuntime].RuntimeType
+		c.Runtimes[name].RuntimeConfigPath = c.Runtimes[c.DefaultRuntime].RuntimeConfigPath
+		c.Runtimes[name].RuntimeRoot = c.Runtimes[c.DefaultRuntime].RuntimeRoot
+	}
+
 	// Validate if runtime_path does exist for each runtime
 	for name, handler := range c.Runtimes {
 		if err := handler.Validate(name); err != nil {
@@ -1742,6 +1780,11 @@ func (r *RuntimeHandler) RuntimeSupportsMountFlag(flag string) bool {
 	return slices.Contains(r.features.MountOptions, flag)
 }
 
+// RuntimeDefaultAnnotations returns the default annotations for this handler.
+func (r *RuntimeHandler) RuntimeDefaultAnnotations() map[string]string {
+	return r.DefaultAnnotations
+}
+
 func validateAllowedAndGenerateDisallowedAnnotations(allowed []string) (disallowed []string, _ error) {
 	disallowedMap := make(map[string]bool)
 	for _, ann := range annotations.AllAllowedAnnotations {
