@@ -1274,6 +1274,28 @@ var _ = t.Describe("Config", func() {
 			Expect(sut.Runtimes).To(HaveKey(config.DefaultRuntime))
 		})
 
+		It("should succeed with additional runtime with inheritance", func() {
+			// Given
+			f := t.MustTempFile("config")
+			Expect(os.WriteFile(f,
+				[]byte(`
+					[crio.runtime.runtimes.crun]
+					[crio.runtime.runtimes.foo]
+					inherit_default_runtime = true
+				`), 0),
+			).To(Succeed())
+
+			// When
+			err := sut.UpdateFromFile(context.Background(), f)
+
+			// Then
+			Expect(err).ToNot(HaveOccurred())
+			Expect(sut.Runtimes).To(HaveLen(2))
+			Expect(sut.Runtimes).To(HaveKey("foo"))
+			Expect(sut.Runtimes).To(HaveKey(config.DefaultRuntime))
+			Expect(sut.Runtimes["foo"].InheritDefaultRuntime).To(BeTrue())
+		})
+
 		It("should fail when file does not exist", func() {
 			// Given
 			// When
@@ -1458,6 +1480,23 @@ var _ = t.Describe("Config", func() {
 			// Then
 			Expect(err).ToNot(HaveOccurred())
 		})
+
+		It("should succeed with empty runtime type and runtime_config_path when inheriting from default", func() {
+			// Given
+			sut.Runtimes["inherited"] = &config.RuntimeHandler{
+				RuntimeConfigPath: invalidPath, RuntimeType: "invalid", InheritDefaultRuntime: true,
+			}
+			// When
+			err := sut.ValidateRuntimes()
+
+			// Then
+			Expect(err).ToNot(HaveOccurred())
+			Expect(sut.Runtimes).To(HaveKey(sut.DefaultRuntime))
+			Expect(sut.Runtimes).To(HaveKey("inherited"))
+
+			// When
+			Expect(sut.Runtimes["inherited"].RuntimePath).To(Equal(sut.Runtimes[sut.DefaultRuntime].RuntimePath))
+		})
 	})
 
 	t.Describe("RuntimeHandlerFeatures", func() {
